import requests
import logging
globalheaders = {
    "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.119 Safari/537.36"
}

## Common HTTP Util methods

def GetRaw(url, **kwgs):
    if kwgs.get("headers"):
        headers = {**globalheaders, **kwgs.get("headers")}
    else:
        headers = globalheaders
    resp = requests.get(url, headers=headers)
    return resp

def Get(url, **kwgs):
    if kwgs.get("headers"):
        headers = {**globalheaders, **kwgs.get("headers")}
    else:
        headers = globalheaders
    resp = requests.get(url, headers=headers)
    return RespUtil.Parse(resp)

def Post(url, **kwgs):
    if kwgs.get("headers"):
        headers = {**globalheaders, **kwgs.get("headers")}
    else:
        headers = globalheaders
    resp = requests.post(url, data=kwgs.get("data"), json=kwgs.get("json"), headers=headers)
    return RespUtil.Parse(resp)

def Put(url, **kwgs):
    if kwgs.get("headers"):
        headers = {**globalheaders, **kwgs.get("headers")}
    else:
        headers = globalheaders
    resp = requests.put(url, data=kwgs.get("data"), headers=headers)
    return RespUtil.Parse(resp)

def Delete(url, **kwgs):
    if kwgs.get("headers"):
        headers = {**globalheaders, **kwgs.get("headers")}
    else:
        headers = globalheaders
    resp = requests.delete(url, headers=headers)
    return RespUtil.Parse(resp)

# Util class to parse http Response
class RespUtil:
    
    @staticmethod
    def Parse(resp):
        if resp.ok:
            try:
                r = resp.json()
            except Exception as e:
                logging.info(e)
                r = resp.text
            finally:
                return r    


from requestutil import *
import logging
from fastai.core import *


## Common Data Util methods

def downloaderV1(url, fname=None, folder=None):
    """
    Retirve the url content & save into file name {fname}
    """
    if not fname:
        fname = url.split("/")[-1]
    resp = GetRaw(url)
    try:
        if folder: 
          p = Path(folder); p.mkdir(exist_ok=True)
          if not str(folder).endswith("/"):
            folder = folder + "/"
          fname = folder + fname
        with open(fname, 'wb') as f: f.write(resp.content)
    except Exception as e:
        print("something went wrong while writing.")
        print(e)


from setuptools import setup, find_packages

with open("README.md") as f:
    longDesc = f.read()


setup(
    name="balautil",
    version="0.1.2",
    author="Bala Prasanna",
    author_email="balaprasannav2009@gmail.com",
    description="A Common machine learning util Collection package",
    long_description=longDesc,
    long_description_content_type="text/markdown",
    url="https://github.com/balaprasanna/balautil",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "requests",
        "plotly",
        "fastai"
    ],
)
